@@ -3,7 +3,7 @@ require(knitr)
 opts_chunk$set(engine='R', tidy=FALSE)
 
 ## ---- echo = TRUE, cache = TRUE, fig = TRUE, fig.width = 8, fig.height = 7----
-library(mkin)
+library("mkin", quietly = TRUE)
 # Define the kinetic model
 m_SFO_SFO_SFO <- mkinmod(parent = mkinsub("SFO", "M1"),
                          M1 = mkinsub("SFO", "M2"),
