@@ -18,10 +18,6 @@
 
 context("Calculation of FOCUS chi2 error levels")
 
-SFO_SFO.ff <- mkinmod(parent = list(type = "SFO", to = "m1"),
-                      m1 = list(type = "SFO"),
-                      use_of_ff = "max", quiet = TRUE)
-
 errmin.FOCUS_2006_D_rounded = data.frame(
   err.min = c(0.0640, 0.0646, 0.0469),
   n.optim = c(4, 2, 2),
@@ -36,16 +32,13 @@ errmin.FOCUS_2006_E_rounded = data.frame(
 
 test_that("Chi2 error levels for FOCUS D are as in mkin 0.9-33", {
 
-  fit <- expect_warning(mkinfit(SFO_SFO.ff, FOCUS_2006_D, quiet = TRUE),
-                        "Observations with value of zero")
-
-
-  expect_equal(round(mkinerrmin(fit), 4),
+  expect_equal(round(mkinerrmin(f_sfo_sfo.ff), 4),
                errmin.FOCUS_2006_D_rounded)
 })
 
 test_that("Chi2 error levels are independent of setting parms.ini that are not in the model", {
 
+  skip_on_cran()
   fit.2 <- expect_warning(mkinfit(SFO_SFO.ff, FOCUS_2006_D, quiet = TRUE,
                                 parms.ini = c(tb = 5)),
                         "Observations with value of zero")
